pub struct AvailableTurn {
    pub src: String,
    pub dst: String,
    pub piece: String,
    pub captured: Option<String>,
    /* private fields */
}
Data which describes the turn that can be played.

In case of a castling turn, king’s source and destination squares will be provided.

Exact turn written in the algebraic chess notation format contains spoilers, so it should be fetched via get_turn function.

Fields

src: String

Source square

dst: String

Destination square

piece: String

Piece making the move

captured: Option<String>

Captured piece

Implementations

Create AvailableTurn

Fetch turn written in chess notation format

Turn info contains spoilers about the turn (checkmate or check), that’s why the turn string is not publicly provided in the struct