Struct chess_turn_engine::AvailableTurn
source · [−]pub struct AvailableTurn {
pub src: String,
pub dst: String,
pub piece: String,
pub captured: Option<String>,
/* private fields */
}Expand description
Data which describes the turn that can be played.
In case of a castling turn, king’s source and destination squares will be provided.
Exact turn written in the algebraic chess notation format contains spoilers,
so it should be fetched via get_turn function.
Fields
src: StringSource square
dst: StringDestination square
piece: StringPiece making the move
captured: Option<String>Captured piece
Implementations